@@ -268,14 +268,7 @@ plot.elife_tstab <- function(
           ylab = "modified scale"
         )
         if (length(which.plot) == 1L && plot) {
-          get(
-            ifelse(
-              packageVersion("ggplot2") >= "3.5.2.9001",
-              "print.ggplot2::ggplot",
-              "print.ggplot"
-            ),
-            envir = loadNamespace("ggplot2")
-          )(g1)
+          print(g1)
         }
         graphs$g1 <- g1
       }
@@ -286,29 +279,12 @@ plot.elife_tstab <- function(
           ylab = "shape"
         )
         if (length(which.plot) == 1L && plot) {
-          get(
-            ifelse(
-              packageVersion("ggplot2") >= "3.5.2.9001",
-              "print.ggplot2::ggplot",
-              "print.ggplot"
-            ),
-            envir = loadNamespace("ggplot2")
-          )(g2)
+          print(g2)
         }
         graphs$g2 <- g2
       }
       if (length(which.plot) == 2L && plot) {
-        lapply(
-          list(g1, g2),
-          get(
-            ifelse(
-              packageVersion("ggplot2") >= "3.5.2.9001",
-              "print.ggplot2::ggplot",
-              "print.ggplot"
-            ),
-            envir = loadNamespace("ggplot2")
-          )
-        )
+        lapply(list(g1, g2), print)
       }
     } else if (object$family == "exp") {
       g1 <- ggplot_thstab(
@@ -317,14 +293,7 @@ plot.elife_tstab <- function(
         ylab = "scale"
       )
       if (plot) {
-        get(
-          ifelse(
-            packageVersion("ggplot2") >= "3.5.2.9001",
-            "print.ggplot2::ggplot",
-            "print.ggplot"
-          ),
-          envir = loadNamespace("ggplot2")
-        )(g1)
+        print(g1)
       }
       graphs$g1 <- g1
     }
