@@ -5,25 +5,29 @@ library(longevity)
 
 set.seed(1234)
 n <- 100L
-x <- samp_elife(n = n,
-           scale = 2,
-           shape = 0.5,
-           lower = low <- runif(n),
-           upper = upp <- runif(n, min = 3, max = 15),
-           type2 = "ltrc",
-           family = "weibull")
+x <- samp_elife(
+  n = n,
+  scale = 2,
+  shape = 0.5,
+  lower = low <- runif(n),
+  upper = upp <- runif(n, min = 3, max = 15),
+  type2 = "ltrc",
+  family = "weibull"
+)
 fit <- fit_elife(
   time = x$dat,
   ltrunc = low,
   event = !x$rcens,
   family = "weibull",
-  export = TRUE)
+  export = TRUE
+)
 fit2 <- fit_elife(
   time = x$dat,
   ltrunc = low,
   event = !x$rcens,
   family = "extweibull",
-  export = TRUE)
+  export = TRUE
+)
 anova(fit, fit2)
 plot(fit2, which.plot = "pp", plot.type = "base")
 plot(fit2, which.plot = "qq", plot.type = "base")
@@ -42,24 +46,27 @@ plot(fit, which.plot = "tmd", plot.type = "ggplot")
 plot(fit, which.plot = "dens", plot.type = "ggplot")
 plot(fit, which.plot = "cdf", plot.type = "ggplot")
 
-expect_true(isTRUE(all.equal(deviance(fit), as.numeric(logLik(fit))*-2)))
+expect_true(isTRUE(all.equal(deviance(fit), as.numeric(logLik(fit)) * -2)))
 expect_true(length(x$dat) == nobs(fit))
 
 set.seed(1234)
 n <- 100L
-x <- samp_elife(n = n,
-                scale = 2,
-                shape = 0.5,
-                lower = low <- runif(n),
-                upper = upp <- runif(n, min = 3, max = 15),
-                type2 = "ltrt",
-                family = "weibull")
+x <- samp_elife(
+  n = n,
+  scale = 2,
+  shape = 0.5,
+  lower = low <- runif(n),
+  upper = upp <- runif(n, min = 3, max = 15),
+  type2 = "ltrt",
+  family = "weibull"
+)
 fit <- fit_elife(
   time = x,
   ltrunc = low,
-  event = upp,
+  upper = upp,
   family = "weibull",
-  export = TRUE)
+  export = TRUE
+)
 plot(fit, which.plot = "pp", plot.type = "base")
 plot(fit, which.plot = "qq", plot.type = "base")
 # Warning because erp == pp w/o censoring
